package ps4;

/**
 * The Blur filter smudges an image by averaging surrounding pixels. This filter
 * applies to a single image.
 * 
 * @author Kei Sakaguchi
 */

public class BlurFilter extends Filter {
	private static final long serialVersionUID = 1L;
	private int repeats = 3; // Apply three times

	public String getFilterName() {
		return "blur";
	}

	protected void filter() 
	// MODIFIES: this
	// EFFECTS: Blurs the pixels in this by averaging their colors
	//    with those of the surrounding pixels.
	{
		for (int i = 0; i < repeats; i++) {
			for (int row = 1; row < getImageHeight() - 1; row++) {
				// starts +1 and ends -1 because you don't need to worry about
				// pixels on the edge
				for (int col = 1; col < getImageWidth() - 1; col++) {
					// average up, down, left, right, and center pixels
					int newRed = (getRed(row, col - 1) + getRed(row - 1, col)
							+ getRed(row, col + 1) + getRed(row + 1, col) + getRed(row, col)) / 5;
					int newGreen = (getGreen(row, col - 1) + getGreen(row - 1, col)
							+ getGreen(row, col + 1) + getGreen(row + 1, col) + getGreen(
							row, col)) / 5;
					int newBlue = (getBlue(row, col - 1) + getBlue(row - 1, col)
							+ getBlue(row, col + 1) + getBlue(row + 1, col) + getBlue(
							row, col)) / 5;

					pixels.setColors(row, col, newRed, newGreen, newBlue);
				}
			}
		}
	}
}
