package ps4;

import java.awt.Image;
import java.util.Vector;

/**
 * Super class for multi-image filter effects.
 * Inherits all methods from BasicFilter, but uses new constructor.
 * @author Daniel Marcus
 */

public abstract class MultiFilter extends Filter 
{
	// OVERVIEW: A MultiFilter is a filter that involves multiple images.
	//    In addition to the primary image, there is a collection of zero or
	//    more additional images.
	
	private static final long serialVersionUID = 1L;
	
	// Rep:
	protected Vector<Image> images;
	protected Vector<Pixels> pixels;
	
	// Rep Invariant:
	//   images.size() == pixels.size()
	
	/**
	 * Constructor for multiple images.
	 * Initializes each image and puts data into arrays.
	 * @param names : list of image names to be filtered
	 */
	public MultiFilter() {
		super ();
		images = new Vector<Image>();
		pixels = new Vector<Pixels>();
	}

	protected void addImage (Image p_image) 
	// REQUIRES: The primary image has been set
	// MODIFIES: this
	// EFFECTS: Adds p_image to the secondary images of this.
	{
		assert image != null;
		images.add(p_image);
		pixels.add(new Pixels(p_image));
	}
	
	protected int getMinimumWidth()
	// EFFECTS: Returns the minimum width of all the images (including the primary image).
	{
		int width = getImageWidth();
		for (Image img : images) {
			if (img.getWidth(null) < width) {
				width = img.getWidth(null);
			}
		}
		return width;
	}

	protected int getMinimumHeight()
	// EFFECTS: Returns the minimum height of all the images (including the primary image).
	{
		int height = getImageHeight();
		for (Image img : images) {
			if (img.getHeight(null) < height) {
				height = img.getHeight(null);
			}
		}
		return height;
	}
	
	protected Pixels getImagePixels(int ind) 
	// REQUIRES: 0 <= ind < images.size()
	// EFFECTS: Returns the Pixels associated with image ind.
	{
		assert 0 <= ind;
		assert ind < pixels.size();
		return pixels.get(ind);
	}
	
	protected int getNumberSecondary()
	// EFFECTS: Returns the number of secondary images
	{
		return images.size();
	}
}